==> haskell-opentelemetry-0.8.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-HPecc37BAVE8t5psjRWOwz
key:                  opentelemetry-0.8.0-HPecc37BAVE8t5psjRWOwz
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  dc2e1a1a43988b0c4b34ec525435e650
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-HPecc37BAVE8t5psjRWOwz
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    ghc-trace-events-0.1.2.8-AXrbrbo7fa5AubaYk3VnX7
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-opentelemetry-0.8.0-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-opentelemetry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 opentelemetry
version:              0.8.0
visibility:           public
id:                   opentelemetry-0.8.0-5ZxVinSF9ag4F0Lc9DWD4Q
key:                  opentelemetry-0.8.0-5ZxVinSF9ag4F0Lc9DWD4Q
license:              Apache-2.0
maintainer:           ethercrow@gmail.com
author:               Dmitry Ivanov
description:          The OpenTelemetry Haskell Client https://opentelemetry.io
category:             OpenTelemetry
abi:                  27577268264d8fe0d5683f26d83c85b5
exposed:              True
exposed-modules:
    OpenTelemetry.Eventlog OpenTelemetry.Eventlog_Internal
    OpenTelemetry.Metrics_Internal OpenTelemetry.Propagation
    OpenTelemetry.SpanContext

import-dirs:          /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/opentelemetry-0.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-opentelemetry
hs-libraries:         HSopentelemetry-0.8.0-5ZxVinSF9ag4F0Lc9DWD4Q
depends:
    base-4.16.4.0 bytestring-0.11.4.0 exceptions-0.10.4
    ghc-trace-events-0.1.2.9-FI8xtj0TQjuI48HJs0fG9x
    hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj

haddock-interfaces:
    /usr/share/doc/haskell-opentelemetry/html/opentelemetry.haddock

haddock-html:         /usr/share/doc/haskell-opentelemetry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
